import Tabs from '@/components/Tabs';
import services from '@/services';
import { formatNumber } from '@/utils/ui';
import { useRequest } from 'ahooks';
import { Flex, Progress, Space } from 'antd';
import dayjs from 'dayjs';
import { memo, useEffect, useMemo, useState } from 'react';
import { useGlobalModalServices } from '../../provider';

import EmptySpace from '@/components/EmptySpace';
import LineCharts from '../../components/IndLineCharts';
import TopSarch from '../../components/TopSarch';
import styles from './index.less';
/**中心城区 */
export const zxcq=['新都区','锦江区','龙泉驿区','金牛区','武侯区','温江区','青白江区','新津区','成华区','双流区','青羊区','郫都区']
/**城市新区 */
export const csxq=['高新区','天府新区','东部新区']
/**郊区新城 */
export const jqxc=['简阳市','都江堰市','彭州市','邛崃市','崇州市','金堂县','大邑县','蒲江县']
/**行政处罚modal */
const AdministPunish = (props: any) => {
  const { dispatch } = useGlobalModalServices();
  const [areaKey, setAreaKey] = useState('all');
  const [searchTime, setSearchTime] = useState({
    key: 'month',
    startTime: dayjs().startOf('month').format('YYYY-MM-DD'),
    endTime: dayjs().endOf('month').format('YYYY-MM-DD'),
  });
  const commonValueStyle = {
    background: 'linear-gradient(180deg, #AAFFF6 0%, #25BBFF 100%)',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
    fontFamily: 'D-DIN',
    fontSize: '36px',
    fontWeight: 700,
    lineHeight: 1.1,
  };

  const commonLabelStyle = {
    color: '#BCCEE9',
    // fontFamily: '微软雅黑',
    fontSize: '20px',
    fontWeight: 400,
    lineHeight: 1.1,
  };

  const commonUnitStyle = {
    color: 'rgb(188, 206, 233)',
    // fontFamily: '微软雅黑',
    fontSize: '14px',
    fontWeight: 400,
    lineHeight: 1.1,
  };
  const pieData = useMemo(() => {
    return [
      {
        name: '简易程序',
        value: 1234,
        percent: '16',
      },
      {
        name: '普通程序',
        value: 1234,
        percent: '16',
      },
    ];
  }, []);

  //总体统计
  const { data: fkjezs } = useRequest(
    () =>
      services.DataBase.getSjdzInfoData({
        typeCode: 'zzcc-xzcf-fkjezs',
        params: {
          ...searchTime,
        },
      }),
    {
      refreshDeps: [searchTime],
    },
  );
  //处罚趋势年
  const { data: cfqsYear } = useRequest(
    () =>
      services.DataBase.getSjdzInfoData({
        typeCode: 'zzcc-xzcf-aysllb',
        params: {
          ...searchTime,
        },
      }),
    {
      refreshDeps: [searchTime],
      ready: searchTime.key === 'year',
    },
  );
  //处罚趋势
  const { data: cfqsMonth } = useRequest(
    () =>
      services.DataBase.getSjdzInfoData({
        typeCode: 'zzcc-xzcf-aysllb',
        params: {
          ...searchTime,
        },
      }),
    {
      refreshDeps: [searchTime],
    },
  );
  const qsList = useMemo(() => {
    console.log(cfqsYear);
    if (searchTime.key === 'year') {
      return cfqsYear?.data?.data?.records?.map((item) => ({
        name: item?.month,
        value: item?.num,
      }));
    } else {
      return cfqsMonth?.data?.data?.records?.map((item) => ({
        name: item?.month,
        value: item?.num,
      }));
    }
  }, [cfqsYear, cfqsMonth, searchTime]);

  //办案数量top5
  const { data: qysl } = useRequest(
    () =>
      services.DataBase.getSjdzInfoData({
        typeCode: 'zzcc-xzcf-qysl',
        params: {
          ...searchTime,
        },
      }),
    {
      refreshDeps: [searchTime],
    },
  );

  const baList = useMemo(() => {
    let list;
    if (areaKey === 'all') {
      list = qysl?.data?.data?.records?.slice(0, 5);
    }
    if (areaKey === 'zx') {
      list = qysl?.data?.data?.records
        ?.filter((item) => zxcq.includes(item?.gridName))
        ?.slice(0, 5);
    }
    if (areaKey === 'xc') {
      list = qysl?.data?.data?.records
        ?.filter((item) => csxq.includes(item?.gridName))
        ?.slice(0, 5);
    }
    if (areaKey === 'jq') {
      list = qysl?.data?.data?.records
        ?.filter((item) => jqxc.includes(item?.gridName))
        ?.slice(0, 5);
    }
    return list?.map((item) => ({
      ...item,
      percent: (
        (item?.num / list?.reduce((acc, it) => acc + (it?.num || 0), 0)) *
        100
      ).toFixed(2),
    }));
  }, [qysl, areaKey]);

  //违法行为类别top5
  const { data: wfxwsl } = useRequest(
    () =>
      services.DataBase.getSjdzInfoData({
        typeCode: 'zzcc-xzcf-wfxwsl',
        params: {
          ...searchTime,
        },
      }),
    {
      refreshDeps: [searchTime],
    },
  );

  const wfList = useMemo(() => {
    const list = wfxwsl?.data?.data?.records?.slice(0, 5);
    console.log(list);
    return list?.map((item) => ({
      ...item,
      percent: (
        (item?.num / list?.reduce((acc, it) => acc + (it?.num || 0), 0)) *
        100
      ).toFixed(2),
    }));
  }, [wfxwsl]);

  useEffect(() => {
    props.modalDispatch.setOptions({
      headerLeft: () => {
        return (
          <TopSarch
            items={[
              {
                key: 'month',
                label: '本月',
              },
              {
                key: 'year',
                label: '本年',
              },
            ]}
            onChange={(e) => {
              console.log(e);
              setSearchTime(e);
            }}
          />
        );
      },
    });
  }, []);
  return (
    <div className={styles.container}>
      <div className={styles.topWarp}>
        <div className={styles.totalWarp}>
          <div className={styles.title}>总体情况</div>
          <div className={styles.content}>
            <div
              className={styles.itemS}
              onClick={() => {
                dispatch.push('AdministPunishList', {
                  headerLeft: () => {
                    return (
                      <div
                        style={{
                          color: 'rgb(43, 218, 255)',
                          fontSize: 18,
                          marginLeft: 20,
                        }}
                      >
                        备注：简易程序的案件不在此列表
                      </div>
                    );
                  },
                  props: {
                   searchTime
                  },
                });
              }}
            >
              <div className={styles.label}>
                <img
                  src={require('@/assets/images/administPunish/cfIcon.png')}
                  alt=""
                  className={styles.icon}
                />
                <span>行政处罚件数</span>
              </div>
              <div className={styles.desc}>
                <div style={commonValueStyle}>
                  {formatNumber(fkjezs?.data?.data?.records?.[0].cfsl)?.num}
                  <span style={commonUnitStyle}>
                    {formatNumber(fkjezs?.data?.data?.records?.[0].cfsl)?.unit}
                  </span>
                </div>

                {/* <div>
                  <span>环比</span>
                  <span>
                    <CaretUpOutlined style={{ color: 'rgb(29, 187, 138)' }} />
                    <CaretDownOutlined style={{ color: 'red' }} />
                  </span>
                  <span className={styles.count}>0.25</span>
                  <span>%</span>
                </div> */}
              </div>
            </div>
            <div
              className={styles.itemS}
              style={{ marginTop: 10 }}
              onClick={() => {
                dispatch.push('AdministPunishList', {
                 
                  headerLeft: () => {
                    return (
                      <div
                        style={{
                          color: 'rgb(43, 218, 255)',
                          fontSize: 18,
                          marginLeft: 20,
                        }}
                      >
                        备注：简易程序的案件不在此列表
                      </div>
                    );
                  },
                  props: {
                    searchTime
                   },
                });
              }}
            >
              <div className={styles.label}>
                <img
                  src={require('@/assets/images/administPunish/fkIcon.png')}
                  alt=""
                  className={styles.icon}
                />
                <span>罚款金额</span>
              </div>
              <div className={styles.desc}>
                <div style={commonValueStyle}>
                  {formatNumber(fkjezs?.data?.data?.records?.[0].fkze)?.num}
                  <span style={commonUnitStyle}>
                    {
                      formatNumber(fkjezs?.data?.data?.records?.[0].fkze, {
                        one: '元',
                        myriad: '万元',
                      })?.unit
                    }
                  </span>
                </div>
                {/* <div>
                  <span>环比</span>
                  <span>
                    <CaretUpOutlined style={{ color: 'rgb(29, 187, 138)' }} />
                    <CaretDownOutlined style={{ color: 'red' }} />
                  </span>
                  <span className={styles.count}>0.25</span>
                  <span>%</span>
                </div> */}
              </div>
            </div>
          </div>
        </div>
        <div className={styles.tendency}>
          <div className={styles.title}>行政处罚趋势</div>
          <div className={styles.unit}>单位：件</div>
          <div style={{ width: '100%' }}>
            <LineCharts data={qsList} style={{ width: 1000, height: 150 }} />
          </div>
        </div>
      </div>
      <div className={styles.bottomWarp}>
        <div className={styles.breakTop}>
          <div className={styles.title}>违法行为类型TOP5</div>
          <div className={styles.content}>
            {wfList?.map((item, index) => {
              return (
                <div
                  className={styles.litsItem}
                  key={index}
                  onClick={() => {
                    dispatch.push('AdministPunishList', {
                       title:`${item?.wfxwlx}行政处罚列表`,
                      headerLeft: () => {
                        return (
                          <div
                            style={{
                              color: 'rgb(43, 218, 255)',
                              fontSize: 18,
                              marginLeft: 20,
                            }}
                          >
                            备注：简易程序的案件不在此列表
                          </div>
                        );
                      },
                      props: {
                        searchTime
                       },
                    });
                  }}
                >
                  <Flex justify="space-between">
                    <div className={styles.name}>{item?.wfxwlx}</div>
                    <Space size={10} className={styles.numBox}>
                      <div className={styles.num}>
                        <span>{item?.num}</span>
                        <span>件</span>
                      </div>
                      <div className={styles.num}>
                        <span>{Number(item?.percent ?? 0)}</span>
                        <span>%</span>
                      </div>
                    </Space>
                  </Flex>

                  <Progress
                    size={{ height: 15 }}
                    percent={item?.percent}
                    showInfo={false}
                    strokeColor={{ from: '#79FFD1', to: '#00B9FF' }}
                    status="active"
                  />
                </div>
              );
            })}
          </div>
        </div>

        <div className={styles.hightTop}>
          <div className={styles.title}>办案数量TOP5</div>
          <Tabs
            style={{
              background: 'transparent',
              height: '30px',
              marginTop: 10,
            }}
            itemStyle={{
              borderRadius: '25px',
              background: 'rgba(7, 50, 93, 0.8)',
              fontSize: '16px',
              marginLeft: 8,
            }}
            onChange={(e) => {
              setAreaKey(e);
            }}
            itemkey={'key'}
            items={[
              {
                key: 'all',
                label: '全部',
              },
              {
                key: 'zx',
                label: '中心城区',
              },
              {
                key: 'xc',
                label: '城市新区',
              },
              {
                key: 'jq',
                label: '郊区新区',
              },
            ]}
          />
          <div className={styles.content}>
            {baList?.map((item, index) => {
              return (
                <div className={styles.litsItem} key={index}    onClick={() => {
                  dispatch.push('AdministPunishList', {
                   
                    title:`${item?.gridName}行政处罚列表`,
                    headerLeft: () => {
                      return (
                        <div
                          style={{
                            color: 'rgb(43, 218, 255)',
                            fontSize: 18,
                            marginLeft: 20,
                          }}
                        >
                          备注：简易程序的案件不在此列表
                        </div>
                      );
                    },
                    props: {
                      searchTime
                     },
                  });
                }}>
                  <Flex justify="space-between">
                    <div className={styles.name}>{item?.gridName}</div>
                    <Space size={10} className={styles.numBox}>
                      <div className={styles.num}>
                        <span>{item?.num}</span>
                        <span>件</span>
                      </div>
                      <div className={styles.num}>
                        <span>{Number(item?.percent ?? 0)}</span>
                        <span>%</span>
                      </div>
                    </Space>
                  </Flex>

                  <Progress
                    size={{ height: 15 }}
                    percent={item?.percent}
                    showInfo={false}
                    strokeColor={{ from: '#79FFD1', to: '#00B9FF' }}
                    status="active"
                  />
                </div>
              );
            })}
          </div>
        </div>

        <div className={styles.transaction}>
          <div className={styles.title}>程序类型</div>
          {/* <PieChart
            style={{ width: '100%', flexDirection: 'column' }}
            chartStyle={{ width: 180, height: 180 }}
            labelClassName={styles.labelClassName}
            // labelStyle={{ height: 175, overflow: 'auto', width: 293 }}
            data={pieData || []}
            labelStyle={{ maxWidth: 100 }}
            color={['#ff9b5d', '#ffe335']}
          /> */}
          <EmptySpace />
        </div>
      </div>
    </div>
  );
};
export default memo(AdministPunish);
